==> 0.1.4.tar.gz: lib/repo/feed_repository.dart <==
import 'dart:async';
import 'dart:convert';
// import 'dart:io';
// import 'package:dio/dio.dart';
import 'package:feed_plugin/models/hashtag.dart';
import 'package:feed_plugin/models/hashtagPostsModel.dart';
import 'package:feed_plugin/models/post_comment_model.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/replyCommentModel.dart';
import 'package:feed_plugin/models/report_model.dart';
import 'package:feed_plugin/models/report_sub_type_model.dart';
import 'package:feed_plugin/models/report_type_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/service/http_service.dart';

class FeedRepository {
  final HttpService _httpService;

  FeedRepository(this._httpService) : assert(_httpService != null);

  Future<List<PostModel>> loadPosts() {
    return _httpService.fetchAllPosts().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> posts = json.decode(data.body);
        List<PostModel> postsList =
            posts.map((i) => PostModel.fromJson(i)).toList();
        return postsList;
      } else {
        return List<PostModel>.from([]);
      }
    });
  }

  Future<PostModel> addPost(user, title, description, type, attachedUrl) {
    return _httpService
        .addPost(
            user: user,
            description: description,
            type: type,
            attachedUrl: attachedUrl,
            title: title)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        List<dynamic> res = json.decode(data.body);
        List<PostModel> postData =
            res.map((i) => PostModel.fromJson(i)).toList();
        if (postData[0] != null) return postData[0];

        return null;
      }
      return null;
    });
  }

  Future<List<ReportTypeModel>> fetchAllReports() {
    return _httpService.fetchAllReports().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportTypeModel> reportsTypeList =
            reports.map((i) => ReportTypeModel.fromJson(i)).toList();
        return reportsTypeList;
      } else {
        return List<ReportTypeModel>.from([]);
      }
    });
  }

  Future<List<ReportSubTypeModel>> fetchSubReport(reportTypeId) {
    return _httpService.fetchSubReport(reportTypeId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportSubTypeModel> reportsSubTypeList =
            reports.map((i) => ReportSubTypeModel.fromJson(i)).toList();
        return reportsSubTypeList;
      } else {
        return List<ReportSubTypeModel>.from([]);
      }
    });
  }

  Future<UserModel> fetchUserData(userId) {
    return _httpService.fetchUser(userId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> res = json.decode(data.body);
        dynamic userData = res[0];
        UserModel user = UserModel.fromJson(userData);
        return user;
      } else {
        return null;
      }
    });
  }

  Future<ReportModel> addReport(typeId, userId, postId) {
    return _httpService
        .addReport(typeId: typeId, userId: userId, postId: postId)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);
        ReportModel reportData = ReportModel.fromJson(res[0]);
        return reportData;
      }
      return null;
    });
  }

  Future<bool> updatePostReport(postId) {
    return _httpService.updatePostReport(postId: postId).then((data) async {
      if (data.statusCode >= 200) {
        return true;
      }
      return false;
    });
  }

  Future<UserModel> authenticateUser(
      firstName, lastName, about, profileImg, token, socialMedia) {
    return _httpService
        .authenticateUser(
      firstName: firstName,
      lastName: lastName,
      about: about,
      profileImg: profileImg,
      token: token,
    )
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);
        UserModel userData = UserModel.fromJson(res);
        if (socialMedia != null) {
          await _httpService
              .updateUserMedia(socialMedia: socialMedia, userId: userData.id)
              .then((user) => {
                    if (data.statusCode >= 200 && data.statusCode < 300)
                      {
                        userData = UserModel.fromJson(json.decode(data.body)),
                      }
                    else
                      {userData = null}
                  });
        }
        return userData;
      }
      return null;
    });
  }

  Future<bool> removeReport(reportId) {
    return _httpService.removeReport(reportId: reportId).then((data) async {
      if (data.statusCode == 200) {
        return true;
      }
      return false;
    });
  }

  Future<bool> removeComment(commentId) {
    return _httpService.removeComment(commentId: commentId).then((data) async {
      if (data.statusCode == 200) {
        return true;
      }
      return false;
    });
  }

  Future<List<ReportModel>> fetchPostReports(postId) {
    return _httpService.fetchReportByPostId(postId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportModel> reportsList =
            reports.map((i) => ReportModel.fromJson(i)).toList();
        return reportsList;
      } else {
        return List<ReportModel>.from([]);
      }
    });
  }

  Future<List<PostCommentModel>> fetchPostComments(postId) async {
    return _httpService.fetchCommentsByPostId(postId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> comments = json.decode(data.body);
        List<PostCommentModel> commentsList =
            comments.map((i) => PostCommentModel.fromJson(i)).toList();
        return commentsList;
      } else {
        return List<PostCommentModel>.from([]);
      }
    });
  }

  Future<List<PostModel>> fetchPostsByUserId(id) async {
    return _httpService.fetchPostsByUserId(id).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> posts = json.decode(data.body);
        List<PostModel> postsList =
            posts.map((i) => PostModel.fromJson(i)).toList();
        return postsList;
      } else {
        return List<PostModel>.from([]);
      }
    });
  }

  Future<List<ReportModel>> fetchFavoritePosts(currentUserId, saveId) async {
    return _httpService
        .fetchFavoritePosts(currentUserId, saveId)
        .then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> posts = json.decode(data.body);
        List<ReportModel> postsList =
            posts.map((i) => ReportModel.fromJson(i)).toList();
        return postsList;
      } else {
        return List<ReportModel>.from([]);
      }
    });
  }

  Future<List<ReportSubTypeModel>> fetchAllSubType() async {
    return _httpService.fetchAllSubType().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportSubTypeModel> reportsSubTypeList =
            reports.map((i) => ReportSubTypeModel.fromJson(i)).toList();
        return reportsSubTypeList;
      } else {
        return List<ReportSubTypeModel>.from([]);
      }
    });
  }

  Future<bool> removePost(postId) {
    return _httpService.removePost(postId: postId).then((data) async {
      if (data.statusCode == 200) {
        return true;
      }
      return false;
    });
  }

  Future<List<HashtagModel>> getAllHashtags() {
    return _httpService.getAllHashtags().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> tags = json.decode(data.body);
        List<HashtagModel> tagsList =
            tags.map((i) => HashtagModel.fromJson(i)).toList();
        return tagsList;
      } else {
        return List<HashtagModel>.from([]);
      }
    });
  }

  Future<HashtagPostsModel> addhashtagPosts(tagId, postId) {
    return _httpService
        .addhashtagPosts(tagId: tagId, postId: postId)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);
        HashtagPostsModel tagPostData = HashtagPostsModel.fromJson(res[0]);
        return tagPostData;
      }
      return null;
    });
  }

  Future<HashtagModel> addNewhashtag(tagName) {
    return _httpService.addNewhashtag(tagName: tagName).then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);
        HashtagModel tagData = HashtagModel.fromJson(res[0]);
        return tagData;
      }
      return null;
    });
  }

  Future<List<HashtagPostsModel>> getHashtagPostByTagName(String tagName) {
    return _httpService
        .getHashtagByTagName(tagName.substring(1))
        .then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> tags = json.decode(data.body);
        List<HashtagPostsModel> tagsList =
            tags.map((i) => HashtagPostsModel.fromJson(i)).toList();
        return tagsList;
      } else {
        return null;
      }
    });
  }

  Future<List<UserModel>> getUsersRandom(skip) {
    return _httpService.getUsersRandom(skip).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> users = json.decode(data.body);
        List<UserModel> usersList =
            users.map((i) => UserModel.fromJson(i)).toList();
        return usersList;
      } else {
        return null;
      }
    });
  }

  Future<ReplyCommentModel> addReplyComment(postComments, user, comment) {
    return _httpService
        .addReplyComment(
            postComments: postComments, user: user, comment: comment)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        List<dynamic> res = json.decode(data.body);
        ReplyCommentModel replyComment = ReplyCommentModel.fromJson(res[0]);
        if (replyComment!= null) return replyComment;

        return null;
      }
      return null;
    });
  }

  Future<List<ReplyCommentModel>> getReplayCommentsList() {
    return _httpService.getReplayCommentsList().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> users = json.decode(data.body);
        List<ReplyCommentModel> replyList =
            users.map((i) => ReplyCommentModel.fromJson(i)).toList();
        return replyList;
      } else {
        return null;
      }
    });
  }

    Future<bool> removeReplyComment(replyId) {
    return _httpService.removeReplyComment(replyId: replyId).then((data) async {
      if (data.statusCode == 200) {
        return true;
      }
      return false;
    });
  }
  // Future<List<String>> uploadFile(file) {
  // return _httpService.uploadFile(file: file).then((data) async {
  //   if (data.statusCode == 200) {
  //     List<dynamic> url = json.decode(data.body);
  //     // List<ReportModel> reportsList =
  //     //     reports.map((i) => ReportModel.fromJson(i)).toList();
  //     return url[0];
  //   } else {
  // return null;
  //   }
  // });
  // }

  // Future<Response> sendFile(File file) async {
  //   try {
  //     String url = "https://feed-content.fra1.digitaloceanspaces.com";
  //     Dio dio = new Dio();
  //     var len = file.lengthSync();
  //     // await file.length();
  //     var response = await dio.put(url,
  //         data: file.openRead(),
  //         options: Options(headers: {
  //           Headers.contentLengthHeader: len,
  //         } // set content-length
  //             ));
  //     print("#############################################");
  //     print(response);
  //     return response;
  //   } catch (e) {
  //     print(e);
  //   }
  // }
}

==> 0.1.23.tar.gz: lib/repo/feed_repository.dart <==
import 'dart:async';
import 'dart:convert';
// import 'dart:io';
// import 'package:dio/dio.dart';
import 'package:feed_plugin/models/hashtag.dart';
import 'package:feed_plugin/models/hashtagPostsModel.dart';
import 'package:feed_plugin/models/poll_option_model.dart';
import 'package:feed_plugin/models/poll_question_model.dart';
import 'package:feed_plugin/models/poll_vote_model.dart';
import 'package:feed_plugin/models/post_comment_model.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/replyCommentModel.dart';
import 'package:feed_plugin/models/report_model.dart';
import 'package:feed_plugin/models/report_sub_type_model.dart';
import 'package:feed_plugin/models/report_type_model.dart';
import 'package:feed_plugin/models/story.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/service/http_service.dart';

class FeedRepository {
  final HttpService _httpService;

  FeedRepository(this._httpService) : assert(_httpService != null);

  Future<List<PostModel>> loadPosts() {
    return _httpService.fetchAllPosts().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> posts = json.decode(data.body);
        List<PostModel> postsList =
            posts.map((i) => PostModel.fromJson(i)).toList();
        return postsList;
      } else {
        return List<PostModel>.from([]);
      }
    });
  }

  Future<PostModel> addPost(
      user, title, description, type, attachedUrl, pollQuestionId) {
    return _httpService
        .addPost(
            user: user,
            description: description,
            type: type,
            attachedUrl: attachedUrl,
            title: title,
            pollQuestionId: pollQuestionId)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        List<dynamic> res = json.decode(data.body);
        List<PostModel> postData =
            res.map((i) => PostModel.fromJson(i)).toList();
        if (postData[0] != null) return postData[0];

        return null;
      }
      return null;
    });
  }

  Future<List<ReportTypeModel>> fetchAllReports() {
    return _httpService.fetchAllReports().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportTypeModel> reportsTypeList =
            reports.map((i) => ReportTypeModel.fromJson(i)).toList();
        return reportsTypeList;
      } else {
        return List<ReportTypeModel>.from([]);
      }
    });
  }

  Future<List<ReportSubTypeModel>> fetchSubReport(reportTypeId) {
    return _httpService.fetchSubReport(reportTypeId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportSubTypeModel> reportsSubTypeList =
            reports.map((i) => ReportSubTypeModel.fromJson(i)).toList();
        return reportsSubTypeList;
      } else {
        return List<ReportSubTypeModel>.from([]);
      }
    });
  }

  Future<UserModel> fetchUserData(userId) {
    return _httpService.fetchUser(userId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> res = json.decode(data.body);
        dynamic userData = res[0];
        UserModel user = UserModel.fromJson(userData);
        return user;
      } else {
        return null;
      }
    });
  }

  Future<ReportModel> addReport(typeId, userId, postId) {
    return _httpService
        .addReport(typeId: typeId, userId: userId, postId: postId)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);
        ReportModel reportData = ReportModel.fromJson(res[0]);
        return reportData;
      }
      return null;
    });
  }

  Future<bool> updatePostReport(postId) {
    return _httpService.updatePostReport(postId: postId).then((data) async {
      if (data.statusCode >= 200) {
        return true;
      }
      return false;
    });
  }

  Future<UserModel> authenticateUser(
      firstName, lastName, about, profileImg, token, socialMedia) {
    return _httpService
        .authenticateUser(
      firstName: firstName,
      lastName: lastName,
      about: about,
      profileImg: profileImg,
      token: token,
    )
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);
        UserModel userData = UserModel.fromJson(res);
        if (socialMedia != null) {
          await _httpService
              .updateUserMedia(socialMedia: socialMedia, userId: userData.id)
              .then((user) => {
                    if (data.statusCode >= 200 && data.statusCode < 300)
                      {
                        userData = UserModel.fromJson(json.decode(data.body)),
                      }
                    else
                      {userData = null}
                  });
        }
        return userData;
      }
      return null;
    });
  }

  Future<bool> removeReport(reportId) {
    return _httpService.removeReport(reportId: reportId).then((data) async {
      if (data.statusCode == 200) {
        return true;
      }
      return false;
    });
  }

  Future<bool> removeComment(commentId) {
    return _httpService.removeComment(commentId: commentId).then((data) async {
      if (data.statusCode == 200) {
        return true;
      }
      return false;
    });
  }

  Future<List<ReportModel>> fetchPostReports(postId) {
    return _httpService.fetchReportByPostId(postId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportModel> reportsList =
            reports.map((i) => ReportModel.fromJson(i)).toList();
        return reportsList;
      } else {
        return List<ReportModel>.from([]);
      }
    });
  }

  Future<List<PostCommentModel>> fetchPostComments(postId) async {
    return _httpService.fetchCommentsByPostId(postId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> comments = json.decode(data.body);
        List<PostCommentModel> commentsList =
            comments.map((i) => PostCommentModel.fromJson(i)).toList();
        return commentsList;
      } else {
        return List<PostCommentModel>.from([]);
      }
    });
  }

  Future<List<PostModel>> fetchPostsByUserId(id) async {
    return _httpService.fetchPostsByUserId(id).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> posts = json.decode(data.body);
        List<PostModel> postsList =
            posts.map((i) => PostModel.fromJson(i)).toList();
        return postsList;
      } else {
        return List<PostModel>.from([]);
      }
    });
  }

  Future<List<ReportModel>> fetchFavoritePosts(currentUserId, saveId) async {
    return _httpService
        .fetchFavoritePosts(currentUserId, saveId)
        .then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> posts = json.decode(data.body);
        List<ReportModel> postsList =
            posts.map((i) => ReportModel.fromJson(i)).toList();
        return postsList;
      } else {
        return List<ReportModel>.from([]);
      }
    });
  }

  Future<List<ReportSubTypeModel>> fetchAllSubType() async {
    return _httpService.fetchAllSubType().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportSubTypeModel> reportsSubTypeList =
            reports.map((i) => ReportSubTypeModel.fromJson(i)).toList();
        return reportsSubTypeList;
      } else {
        return List<ReportSubTypeModel>.from([]);
      }
    });
  }

  Future<bool> removePost(postId) {
    return _httpService.removePost(postId: postId).then((data) async {
      if (data.statusCode == 200) {
        return true;
      }
      return false;
    });
  }

  Future<List<HashtagModel>> getAllHashtags() {
    return _httpService.getAllHashtags().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> tags = json.decode(data.body);
        List<HashtagModel> tagsList =
            tags.map((i) => HashtagModel.fromJson(i)).toList();
        return tagsList;
      } else {
        return List<HashtagModel>.from([]);
      }
    });
  }

  Future<HashtagPostsModel> addhashtagPosts(tagId, postId) {
    return _httpService
        .addhashtagPosts(tagId: tagId, postId: postId)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);
        HashtagPostsModel tagPostData = HashtagPostsModel.fromJson(res[0]);
        return tagPostData;
      }
      return null;
    });
  }

  Future<HashtagModel> addNewhashtag(tagName) {
    return _httpService.addNewhashtag(tagName: tagName).then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);
        HashtagModel tagData = HashtagModel.fromJson(res[0]);
        return tagData;
      }
      return null;
    });
  }

  Future<List<HashtagPostsModel>> getHashtagPostByTagName(String tagName) {
    return _httpService
        .getHashtagByTagName(tagName.substring(1))
        .then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> tags = json.decode(data.body);
        List<HashtagPostsModel> tagsList =
            tags.map((i) => HashtagPostsModel.fromJson(i)).toList();
        return tagsList;
      } else {
        return null;
      }
    });
  }

  Future<List<UserModel>> getUsersRandom(skip) {
    return _httpService.getUsersRandom(skip).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> users = json.decode(data.body);
        List<UserModel> usersList =
            users.map((i) => UserModel.fromJson(i)).toList();
        return usersList;
      } else {
        return null;
      }
    });
  }

  Future<ReplyCommentModel> addReplyComment(postComments, user, comment) {
    return _httpService
        .addReplyComment(
            postComments: postComments, user: user, comment: comment)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        List<dynamic> res = json.decode(data.body);
        ReplyCommentModel replyComment = ReplyCommentModel.fromJson(res[0]);
        if (replyComment != null) return replyComment;

        return null;
      }
      return null;
    });
  }

  Future<List<ReplyCommentModel>> getReplayCommentsList() {
    return _httpService.getReplayCommentsList().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> users = json.decode(data.body);
        List<ReplyCommentModel> replyList =
            users.map((i) => ReplyCommentModel.fromJson(i)).toList();
        return replyList;
      } else {
        return null;
      }
    });
  }

  Future<bool> removeReplyComment(replyId) {
    return _httpService.removeReplyComment(replyId: replyId).then((data) async {
      if (data.statusCode == 200) {
        return true;
      }
      return false;
    });
  }

  Future<PollQuestionModel> createPollQuestion(question) {
    return _httpService
        .createPollQuestion(question: question)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);

        print(res);
        PollQuestionModel pollQuestionData = PollQuestionModel.fromJson(res[0]);
        return pollQuestionData;
      }
      return null;
    });
  }

  Future<PollOptionModel> createPollOption(pollQuestion, option) {
    return _httpService
        .createPollOption(pollQuestion: pollQuestion, option: option)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);

        print(res);
        PollOptionModel pollOptionData = PollOptionModel.fromJson(res[0]);
        return pollOptionData;
      }
      return null;
    });
  }

  Future<List<PollOptionModel>> getAllOptions() {
    return _httpService.getAllOptions().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> tags = json.decode(data.body);
        List<PollOptionModel> pollOptionsList =
            tags.map((i) => PollOptionModel.fromJson(i)).toList();
        return pollOptionsList;
      } else {
        return List<PollOptionModel>.from([]);
      }
    });
  }

  Future<List<PollOptionModel>> getOptionsByQuestionId(questionId) {
    return _httpService.getOptionsByQuestionId(questionId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> options = json.decode(data.body);
        List<PollOptionModel> optionsList =
            options.map((i) => PollOptionModel.fromJson(i)).toList();
        return optionsList;
      } else {
        return List<PollOptionModel>.from([]);
      }
    });
  }

  Future<PollVoteModel> createPollVote(pollOption, user) {
    return _httpService
        .createPollVote(pollOption: pollOption, user: user)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);

        print(res);
        PollVoteModel pollVoteData = PollVoteModel.fromJson(res[0]);
        return pollVoteData;
      }
      return null;
    });
  }

  Future<bool> removePollVote(pollVoteId) {
    return _httpService
        .removePollVote(pollVoteId: pollVoteId)
        .then((data) async {
      if (data.statusCode == 200) {
        return true;
      }
      return false;
    });
  }

  Future<List<PollVoteModel>> getAllVotes() {
    return _httpService.getAllVotes().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> tags = json.decode(data.body);
        List<PollVoteModel> pollVotesList =
            tags.map((i) => PollVoteModel.fromJson(i)).toList();
        return pollVotesList;
      } else {
        return List<PollVoteModel>.from([]);
      }
    });
  }

  Future<List<StoryModel>> getAllStories() {
    return _httpService.getAllStories().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> story = json.decode(data.body);
        List<StoryModel> storiesList =
            story.map((i) => StoryModel.fromJson(i)).toList();
        return storiesList;
      } else {
        return List<StoryModel>.from([]);
      }
    });
  }

  Future<List<StoryModel>> getStoriesToday() {
    return _httpService.getAllStories().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> story = json.decode(data.body);
        List<StoryModel> storiesList =
            story.map((i) => StoryModel.fromJson(i)).toList();
        final date = DateTime.now();
        List<StoryModel> storyToday =
            storiesList.where((s) => date.difference(s.createdAt).inDays <= 1).toList();
        return storyToday;
      } else {
        return List<StoryModel>.from([]);
      }
    });
  }

  Future<StoryModel> createStory(text, user, attachedUrl) {
    return _httpService
        .createStory(text: text, attachedUrl: attachedUrl, user: user)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);
        StoryModel storyData = StoryModel.fromJson(res[0]);
        return storyData;
      }
      return null;
    });
  }

  // Future<List<String>> uploadFile(file) {
  // return _httpService.uploadFile(file: file).then((data) async {
  //   if (data.statusCode == 200) {
  //     List<dynamic> url = json.decode(data.body);
  //     // List<ReportModel> reportsList =
  //     //     reports.map((i) => ReportModel.fromJson(i)).toList();
  //     return url[0];
  //   } else {
  // return null;
  //   }
  // });
  // }

  // Future<Response> sendFile(File file) async {
  //   try {
  //     String url = "https://feed-content.fra1.digitaloceanspaces.com";
  //     Dio dio = new Dio();
  //     var len = file.lengthSync();
  //     // await file.length();
  //     var response = await dio.put(url,
  //         data: file.openRead(),
  //         options: Options(headers: {
  //           Headers.contentLengthHeader: len,
  //         } // set content-length
  //             ));
  //     print("#############################################");
  //     print(response);
  //     return response;
  //   } catch (e) {
  //     print(e);
  //   }
  // }
}
